summaryrefslogtreecommitdiffstats
path: root/platform
diff options
context:
space:
mode:
authorTrashguy <trashguy@gmail.com>2024-10-11 12:21:42 -0400
committerSpartan322 <Megacake1234@gmail.com>2024-10-13 15:05:24 -0400
commit9901f655fb46bd345770ad5f4a1638c4051b1816 (patch)
treebb22b4881145f122568c8f2e51e912078ad1b4fc /platform
parent6699ae7897658e44efc3cfb2cba91c11a8f5aa6a (diff)
downloadredot-engine-9901f655fb46bd345770ad5f4a1638c4051b1816.tar.gz
Rebrand Godot 4.3 to Redot
Diffstat (limited to 'platform')
-rw-r--r--platform/android/export/export_plugin.cpp2
-rw-r--r--platform/android/java/app/build.gradle2
-rw-r--r--platform/android/java/build.gradle2
-rw-r--r--platform/android/java/lib/res/mipmap-hdpi/icon.pngbin3762 -> 1412 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-hdpi/icon_foreground.pngbin2998 -> 1752 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-mdpi/icon.pngbin2672 -> 1018 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-mdpi/icon_foreground.pngbin1909 -> 1107 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-xhdpi/icon.pngbin5186 -> 2027 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-xhdpi/icon_foreground.pngbin4490 -> 2435 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-xxhdpi/icon.pngbin8154 -> 2932 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-xxhdpi/icon_foreground.pngbin7415 -> 3945 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-xxxhdpi/icon.pngbin11749 -> 4185 bytes
-rw-r--r--platform/android/java/lib/res/mipmap-xxxhdpi/icon_foreground.pngbin11325 -> 5275 bytes
-rw-r--r--platform/android/java/lib/res/mipmap/icon.pngbin11749 -> 4186 bytes
-rw-r--r--platform/android/java/lib/res/mipmap/icon_foreground.pngbin1909 -> 1177 bytes
-rw-r--r--platform/android/java/lib/src/org/godotengine/godot/Godot.kt6
-rw-r--r--platform/android/java/lib/src/org/godotengine/godot/GodotActivity.kt10
-rw-r--r--platform/android/java/lib/src/org/godotengine/godot/gl/GodotRenderer.java2
-rw-r--r--platform/android/java/lib/src/org/godotengine/godot/input/GodotInputHandler.java2
-rw-r--r--platform/android/java/lib/src/org/godotengine/godot/plugin/GodotPluginRegistry.java10
-rw-r--r--platform/android/java/lib/src/org/godotengine/godot/vulkan/VkRenderer.kt2
-rw-r--r--platform/ios/export/export_plugin.cpp2
-rw-r--r--platform/linuxbsd/SCsub2
-rw-r--r--platform/linuxbsd/detect.py2
-rw-r--r--platform/linuxbsd/freedesktop_screensaver.cpp4
-rw-r--r--platform/linuxbsd/wayland/display_server_wayland.cpp4
-rw-r--r--platform/linuxbsd/x11/display_server_x11.cpp14
-rw-r--r--platform/macos/SCsub2
-rw-r--r--platform/macos/doc_classes/EditorExportPlatformMacOS.xml2
-rw-r--r--platform/web/SCsub8
-rw-r--r--platform/web/detect.py6
-rw-r--r--platform/web/eslint.config.cjs1
-rw-r--r--platform/web/export/export_plugin.cpp4
-rw-r--r--platform/web/js/engine/config.js2
-rw-r--r--platform/web/js/engine/engine.externs.js2
-rw-r--r--platform/web/js/engine/engine.js2
-rw-r--r--platform/windows/SCsub4
-rw-r--r--platform/windows/display_server_windows.cpp2
-rw-r--r--platform/windows/export/export_plugin.cpp12
-rw-r--r--platform/windows/godot.icobin142638 -> 0 bytes
-rw-r--r--platform/windows/godot_console.icobin140380 -> 0 bytes
-rw-r--r--platform/windows/godot_res.rc8
-rw-r--r--platform/windows/godot_res_wrap.rc8
-rw-r--r--platform/windows/redot.icobin0 -> 64957 bytes
-rw-r--r--platform/windows/redot_console.icobin0 -> 56301 bytes
45 files changed, 65 insertions, 64 deletions
diff --git a/platform/android/export/export_plugin.cpp b/platform/android/export/export_plugin.cpp
index d5153fb6c0..1a77496a3b 100644
--- a/platform/android/export/export_plugin.cpp
+++ b/platform/android/export/export_plugin.cpp
@@ -1782,7 +1782,7 @@ String EditorExportPlatformAndroid::get_export_option_warning(const EditorExport
} else {
min_sdk_int = min_sdk_str.to_int();
if (min_sdk_int < OPENGL_MIN_SDK_VERSION) {
- return vformat(TTR("\"Min SDK\" cannot be lower than %d, which is the version needed by the Godot library."), OPENGL_MIN_SDK_VERSION);
+ return vformat(TTR("\"Min SDK\" cannot be lower than %d, which is the version needed by the Redot library."), OPENGL_MIN_SDK_VERSION);
}
}
}
diff --git a/platform/android/java/app/build.gradle b/platform/android/java/app/build.gradle
index 01d5d9ef92..170d9a4376 100644
--- a/platform/android/java/app/build.gradle
+++ b/platform/android/java/app/build.gradle
@@ -282,7 +282,7 @@ task copyAndRenameReleaseAab(type: Copy) {
*/
task validateJavaVersion {
if (JavaVersion.current() != versions.javaVersion) {
- throw new GradleException("Invalid Java version ${JavaVersion.current()}. Version ${versions.javaVersion} is the required Java version for Godot gradle builds.")
+ throw new GradleException("Invalid Java version ${JavaVersion.current()}. Version ${versions.javaVersion} is the required Java version for Redot gradle builds.")
}
}
diff --git a/platform/android/java/build.gradle b/platform/android/java/build.gradle
index f5555289fd..1ee87b99d9 100644
--- a/platform/android/java/build.gradle
+++ b/platform/android/java/build.gradle
@@ -152,7 +152,7 @@ task copyReleaseAARToBin(type: Copy) {
task zipGradleBuild(type: Zip) {
onlyIf { generateGodotTemplates.state.executed || generateDevTemplate.state.executed }
doFirst {
- logger.lifecycle("Generating Godot gradle build template")
+ logger.lifecycle("Generating Redot gradle build template")
}
from(fileTree(dir: 'app', excludes: ['**/build/**', '**/.gradle/**', '**/*.iml']), fileTree(dir: '.', includes: ['gradlew', 'gradlew.bat', 'gradle/**']))
include '**/*'
diff --git a/platform/android/java/lib/res/mipmap-hdpi/icon.png b/platform/android/java/lib/res/mipmap-hdpi/icon.png
index cc6e113e89..8f5f2471f1 100644
--- a/platform/android/java/lib/res/mipmap-hdpi/icon.png
+++ b/platform/android/java/lib/res/mipmap-hdpi/icon.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-hdpi/icon_foreground.png b/platform/android/java/lib/res/mipmap-hdpi/icon_foreground.png
index 75e409ff74..cd15cc55e3 100644
--- a/platform/android/java/lib/res/mipmap-hdpi/icon_foreground.png
+++ b/platform/android/java/lib/res/mipmap-hdpi/icon_foreground.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-mdpi/icon.png b/platform/android/java/lib/res/mipmap-mdpi/icon.png
index e1968fe142..249dea1ce5 100644
--- a/platform/android/java/lib/res/mipmap-mdpi/icon.png
+++ b/platform/android/java/lib/res/mipmap-mdpi/icon.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-mdpi/icon_foreground.png b/platform/android/java/lib/res/mipmap-mdpi/icon_foreground.png
index 982b69be1e..68737ef0b3 100644
--- a/platform/android/java/lib/res/mipmap-mdpi/icon_foreground.png
+++ b/platform/android/java/lib/res/mipmap-mdpi/icon_foreground.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-xhdpi/icon.png b/platform/android/java/lib/res/mipmap-xhdpi/icon.png
index 9281d8da48..122c219716 100644
--- a/platform/android/java/lib/res/mipmap-xhdpi/icon.png
+++ b/platform/android/java/lib/res/mipmap-xhdpi/icon.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-xhdpi/icon_foreground.png b/platform/android/java/lib/res/mipmap-xhdpi/icon_foreground.png
index 726b267ad6..a84f25f82d 100644
--- a/platform/android/java/lib/res/mipmap-xhdpi/icon_foreground.png
+++ b/platform/android/java/lib/res/mipmap-xhdpi/icon_foreground.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-xxhdpi/icon.png b/platform/android/java/lib/res/mipmap-xxhdpi/icon.png
index 7a6b67d273..63287d1f36 100644
--- a/platform/android/java/lib/res/mipmap-xxhdpi/icon.png
+++ b/platform/android/java/lib/res/mipmap-xxhdpi/icon.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-xxhdpi/icon_foreground.png b/platform/android/java/lib/res/mipmap-xxhdpi/icon_foreground.png
index b0c727f74c..9b005204f1 100644
--- a/platform/android/java/lib/res/mipmap-xxhdpi/icon_foreground.png
+++ b/platform/android/java/lib/res/mipmap-xxhdpi/icon_foreground.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-xxxhdpi/icon.png b/platform/android/java/lib/res/mipmap-xxxhdpi/icon.png
index 0881245802..d2b14a6830 100644
--- a/platform/android/java/lib/res/mipmap-xxxhdpi/icon.png
+++ b/platform/android/java/lib/res/mipmap-xxxhdpi/icon.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap-xxxhdpi/icon_foreground.png b/platform/android/java/lib/res/mipmap-xxxhdpi/icon_foreground.png
index 72e6f92b6e..c2c98811bb 100644
--- a/platform/android/java/lib/res/mipmap-xxxhdpi/icon_foreground.png
+++ b/platform/android/java/lib/res/mipmap-xxxhdpi/icon_foreground.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap/icon.png b/platform/android/java/lib/res/mipmap/icon.png
index 0881245802..9134bb24eb 100644
--- a/platform/android/java/lib/res/mipmap/icon.png
+++ b/platform/android/java/lib/res/mipmap/icon.png
Binary files differ
diff --git a/platform/android/java/lib/res/mipmap/icon_foreground.png b/platform/android/java/lib/res/mipmap/icon_foreground.png
index 982b69be1e..d37f142621 100644
--- a/platform/android/java/lib/res/mipmap/icon_foreground.png
+++ b/platform/android/java/lib/res/mipmap/icon_foreground.png
Binary files differ
diff --git a/platform/android/java/lib/src/org/godotengine/godot/Godot.kt b/platform/android/java/lib/src/org/godotengine/godot/Godot.kt
index fa39ccb546..5b5d3e3605 100644
--- a/platform/android/java/lib/src/org/godotengine/godot/Godot.kt
+++ b/platform/android/java/lib/src/org/godotengine/godot/Godot.kt
@@ -353,15 +353,15 @@ class Godot(private val context: Context) : SensorEventListener {
fileAccessHandler,
useApkExpansion,
)
- Log.v(TAG, "Godot native layer initialization completed: $nativeLayerInitializeCompleted")
+ Log.v(TAG, "Redot native layer initialization completed: $nativeLayerInitializeCompleted")
}
if (nativeLayerInitializeCompleted && !nativeLayerSetupCompleted) {
nativeLayerSetupCompleted = GodotLib.setup(commandLine.toTypedArray(), tts)
if (!nativeLayerSetupCompleted) {
- throw IllegalStateException("Unable to setup the Godot engine! Aborting...")
+ throw IllegalStateException("Unable to setup the Redot engine! Aborting...")
} else {
- Log.v(TAG, "Godot native layer setup completed")
+ Log.v(TAG, "Redot native layer setup completed")
}
}
} finally {
diff --git a/platform/android/java/lib/src/org/godotengine/godot/GodotActivity.kt b/platform/android/java/lib/src/org/godotengine/godot/GodotActivity.kt
index 913e3d04c5..0e16f4bc6a 100644
--- a/platform/android/java/lib/src/org/godotengine/godot/GodotActivity.kt
+++ b/platform/android/java/lib/src/org/godotengine/godot/GodotActivity.kt
@@ -72,10 +72,10 @@ abstract class GodotActivity : FragmentActivity(), GodotHost {
val currentFragment = supportFragmentManager.findFragmentById(R.id.godot_fragment_container)
if (currentFragment is GodotFragment) {
- Log.v(TAG, "Reusing existing Godot fragment instance.")
+ Log.v(TAG, "Reusing existing Redot fragment instance.")
godotFragment = currentFragment
} else {
- Log.v(TAG, "Creating new Godot fragment instance.")
+ Log.v(TAG, "Creating new Redot fragment instance.")
godotFragment = initGodotInstance()
supportFragmentManager.beginTransaction().replace(R.id.godot_fragment_container, godotFragment!!).setPrimaryNavigationFragment(godotFragment).commitNowAllowingStateLoss()
}
@@ -85,7 +85,7 @@ abstract class GodotActivity : FragmentActivity(), GodotHost {
protected open fun getGodotAppLayout() = R.layout.godot_app_layout
override fun onDestroy() {
- Log.v(TAG, "Destroying GodotActivity $this...")
+ Log.v(TAG, "Destroying RedotActivity $this...")
super.onDestroy()
}
@@ -96,7 +96,7 @@ abstract class GodotActivity : FragmentActivity(), GodotHost {
private fun terminateGodotInstance(instance: Godot) {
godotFragment?.let {
if (instance === it.godot) {
- Log.v(TAG, "Force quitting Godot instance")
+ Log.v(TAG, "Force quitting Redot instance")
ProcessPhoenix.forceQuit(this)
}
}
@@ -111,7 +111,7 @@ abstract class GodotActivity : FragmentActivity(), GodotHost {
//
// Restarting only the activity, wouldn't be enough unless it did proper cleanup (including
// releasing and reloading native libs or resetting their state somehow and clearing static data).
- Log.v(TAG, "Restarting Godot instance...")
+ Log.v(TAG, "Restarting Redot instance...")
ProcessPhoenix.triggerRebirth(this)
}
}
diff --git a/platform/android/java/lib/src/org/godotengine/godot/gl/GodotRenderer.java b/platform/android/java/lib/src/org/godotengine/godot/gl/GodotRenderer.java
index 7e5e262b2d..42496a9025 100644
--- a/platform/android/java/lib/src/org/godotengine/godot/gl/GodotRenderer.java
+++ b/platform/android/java/lib/src/org/godotengine/godot/gl/GodotRenderer.java
@@ -68,7 +68,7 @@ public class GodotRenderer implements GLSurfaceView.Renderer {
@Override
public void onRenderThreadExiting() {
- Log.d(TAG, "Destroying Godot Engine");
+ Log.d(TAG, "Destroying Redot Engine");
GodotLib.ondestroy();
}
diff --git a/platform/android/java/lib/src/org/godotengine/godot/input/GodotInputHandler.java b/platform/android/java/lib/src/org/godotengine/godot/input/GodotInputHandler.java
index 273774a33d..8b673407c9 100644
--- a/platform/android/java/lib/src/org/godotengine/godot/input/GodotInputHandler.java
+++ b/platform/android/java/lib/src/org/godotengine/godot/input/GodotInputHandler.java
@@ -370,7 +370,7 @@ public class GodotInputHandler implements InputManager.InputDeviceListener {
Collections.sort(joystick.axes);
for (int idx = 0; idx < joystick.axes.size(); idx++) {
//Helps with creating new joypad mappings.
- Log.i(TAG, " - Mapping Android axis " + joystick.axes.get(idx) + " to Godot axis " + idx);
+ Log.i(TAG, " - Mapping Android axis " + joystick.axes.get(idx) + " to Redot axis " + idx);
}
mJoysticksDevices.put(deviceId, joystick);
diff --git a/platform/android/java/lib/src/org/godotengine/godot/plugin/GodotPluginRegistry.java b/platform/android/java/lib/src/org/godotengine/godot/plugin/GodotPluginRegistry.java
index 711bca02e7..8714e9e1b9 100644
--- a/platform/android/java/lib/src/org/godotengine/godot/plugin/GodotPluginRegistry.java
+++ b/platform/android/java/lib/src/org/godotengine/godot/plugin/GodotPluginRegistry.java
@@ -147,11 +147,11 @@ public final class GodotPluginRegistry {
pluginName = metaDataName.substring(GODOT_PLUGIN_V2_NAME_PREFIX.length()).trim();
} else if (metaDataName.startsWith(GODOT_PLUGIN_V1_NAME_PREFIX)) {
pluginName = metaDataName.substring(GODOT_PLUGIN_V1_NAME_PREFIX.length()).trim();
- Log.w(TAG, "Godot v1 plugin are deprecated in Godot 4.2 and higher: " + pluginName);
+ Log.w(TAG, "Redot v1 plugin are deprecated in Redot 4.2 and higher: " + pluginName);
}
if (!TextUtils.isEmpty(pluginName)) {
- Log.i(TAG, "Initializing Godot plugin " + pluginName);
+ Log.i(TAG, "Initializing Redot plugin " + pluginName);
// Retrieve the plugin class full name.
String pluginHandleClassFullName = metaData.getString(metaDataName);
@@ -171,9 +171,9 @@ public final class GodotPluginRegistry {
"Meta-data plugin name does not match the value returned by the plugin handle: " + pluginName + " =/= " + pluginHandle.getPluginName());
}
registry.put(pluginName, pluginHandle);
- Log.i(TAG, "Completed initialization for Godot plugin " + pluginHandle.getPluginName());
+ Log.i(TAG, "Completed initialization for Redot plugin " + pluginHandle.getPluginName());
} catch (Exception e) {
- Log.w(TAG, "Unable to load Godot plugin " + pluginName, e);
+ Log.w(TAG, "Unable to load Redot plugin " + pluginName, e);
}
} else {
Log.w(TAG, "Invalid plugin loader class for " + pluginName);
@@ -181,7 +181,7 @@ public final class GodotPluginRegistry {
}
}
} catch (Exception e) {
- Log.e(TAG, "Unable load Godot Android plugins from the manifest file.", e);
+ Log.e(TAG, "Unable load Redot Android plugins from the manifest file.", e);
}
}
}
diff --git a/platform/android/java/lib/src/org/godotengine/godot/vulkan/VkRenderer.kt b/platform/android/java/lib/src/org/godotengine/godot/vulkan/VkRenderer.kt
index a93a7dbe09..0cb03cc871 100644
--- a/platform/android/java/lib/src/org/godotengine/godot/vulkan/VkRenderer.kt
+++ b/platform/android/java/lib/src/org/godotengine/godot/vulkan/VkRenderer.kt
@@ -107,7 +107,7 @@ internal class VkRenderer {
* Invoked when the render thread is in the process of shutting down.
*/
fun onRenderThreadExiting() {
- Log.d(TAG, "Destroying Godot Engine")
+ Log.d(TAG, "Destroying Redot Engine")
GodotLib.ondestroy()
}
}
diff --git a/platform/ios/export/export_plugin.cpp b/platform/ios/export/export_plugin.cpp
index 580e3ba789..93c1207e34 100644
--- a/platform/ios/export/export_plugin.cpp
+++ b/platform/ios/export/export_plugin.cpp
@@ -1977,7 +1977,7 @@ Error EditorExportPlatformIOS::_export_ios_plugins(const Ref<EditorExportPreset>
plugin_format["initialization"] = plugin_initialization_cpp_code;
plugin_format["deinitialization"] = plugin_deinitialization_cpp_code;
- String plugin_cpp_code = "\n// Godot Plugins\n"
+ String plugin_cpp_code = "\n// Redot Plugins\n"
"void godot_ios_plugins_initialize();\n"
"void godot_ios_plugins_deinitialize();\n"
"// Exported Plugins\n\n"
diff --git a/platform/linuxbsd/SCsub b/platform/linuxbsd/SCsub
index 0802b528f4..d975273bb7 100644
--- a/platform/linuxbsd/SCsub
+++ b/platform/linuxbsd/SCsub
@@ -38,7 +38,7 @@ if env["dbus"]:
if env["use_sowrap"]:
common_linuxbsd.append("dbus-so_wrap.c")
-prog = env.add_program("#bin/godot", ["godot_linuxbsd.cpp"] + common_linuxbsd)
+prog = env.add_program("#bin/redot", ["godot_linuxbsd.cpp"] + common_linuxbsd)
if env["debug_symbols"] and env["separate_debug_symbols"]:
env.AddPostAction(prog, env.Run(platform_linuxbsd_builders.make_debug_linuxbsd))
diff --git a/platform/linuxbsd/detect.py b/platform/linuxbsd/detect.py
index d1de760f34..eba26a3630 100644
--- a/platform/linuxbsd/detect.py
+++ b/platform/linuxbsd/detect.py
@@ -33,7 +33,7 @@ def get_opts():
EnumVariable("linker", "Linker program", "default", ("default", "bfd", "gold", "lld", "mold")),
BoolVariable("use_llvm", "Use the LLVM compiler", False),
BoolVariable("use_static_cpp", "Link libgcc and libstdc++ statically for better portability", True),
- BoolVariable("use_coverage", "Test Godot coverage", False),
+ BoolVariable("use_coverage", "Test Redot coverage", False),
BoolVariable("use_ubsan", "Use LLVM/GCC compiler undefined behavior sanitizer (UBSAN)", False),
BoolVariable("use_asan", "Use LLVM/GCC compiler address sanitizer (ASAN)", False),
BoolVariable("use_lsan", "Use LLVM/GCC compiler leak sanitizer (LSAN)", False),
diff --git a/platform/linuxbsd/freedesktop_screensaver.cpp b/platform/linuxbsd/freedesktop_screensaver.cpp
index cf179b5735..8b22b18232 100644
--- a/platform/linuxbsd/freedesktop_screensaver.cpp
+++ b/platform/linuxbsd/freedesktop_screensaver.cpp
@@ -61,9 +61,9 @@ void FreeDesktopScreenSaver::inhibit() {
String app_name_string = GLOBAL_GET("application/config/name");
CharString app_name_utf8 = app_name_string.utf8();
- const char *app_name = app_name_string.is_empty() ? "Godot Engine" : app_name_utf8.get_data();
+ const char *app_name = app_name_string.is_empty() ? "Redot Engine" : app_name_utf8.get_data();
- const char *reason = "Running Godot Engine project";
+ const char *reason = "Running Redot Engine project";
DBusMessage *message = dbus_message_new_method_call(
BUS_OBJECT_NAME, BUS_OBJECT_PATH, BUS_INTERFACE,
diff --git a/platform/linuxbsd/wayland/display_server_wayland.cpp b/platform/linuxbsd/wayland/display_server_wayland.cpp
index 93096fcdcc..05e5d472da 100644
--- a/platform/linuxbsd/wayland/display_server_wayland.cpp
+++ b/platform/linuxbsd/wayland/display_server_wayland.cpp
@@ -1413,7 +1413,7 @@ DisplayServerWayland::DisplayServerWayland(const String &p_rendering_driver, Win
if (prime_idx) {
print_line(vformat("Found discrete GPU, setting DRI_PRIME=%d to use it.", prime_idx));
- print_line("Note: Set DRI_PRIME=0 in the environment to disable Godot from using the discrete GPU.");
+ print_line("Note: Set DRI_PRIME=0 in the environment to disable Redot from using the discrete GPU.");
setenv("DRI_PRIME", itos(prime_idx).utf8().ptr(), 1);
}
}
@@ -1462,7 +1462,7 @@ DisplayServerWayland::DisplayServerWayland(const String &p_rendering_driver, Win
wd.flags = p_flags;
wd.vsync_mode = p_vsync_mode;
wd.rect.size = p_resolution;
- wd.title = "Godot";
+ wd.title = "Redot";
_show_window();
diff --git a/platform/linuxbsd/x11/display_server_x11.cpp b/platform/linuxbsd/x11/display_server_x11.cpp
index 8a2f83be2d..5d55081e90 100644
--- a/platform/linuxbsd/x11/display_server_x11.cpp
+++ b/platform/linuxbsd/x11/display_server_x11.cpp
@@ -5228,13 +5228,13 @@ void DisplayServerX11::_update_context(WindowData &wd) {
CharString name_str;
switch (context) {
case CONTEXT_EDITOR:
- name_str = "Godot_Editor";
+ name_str = "Redot_Editor";
break;
case CONTEXT_PROJECTMAN:
- name_str = "Godot_ProjectList";
+ name_str = "Redot_ProjectList";
break;
case CONTEXT_ENGINE:
- name_str = "Godot_Engine";
+ name_str = "Redot_Engine";
break;
}
@@ -5242,12 +5242,12 @@ void DisplayServerX11::_update_context(WindowData &wd) {
if (context == CONTEXT_ENGINE) {
String config_name = GLOBAL_GET("application/config/name");
if (config_name.length() == 0) {
- class_str = "Godot_Engine";
+ class_str = "Redot_Engine";
} else {
class_str = config_name.utf8();
}
} else {
- class_str = "Godot";
+ class_str = "Redot";
}
classHint->res_class = class_str.ptrw();
@@ -5638,7 +5638,7 @@ DisplayServerX11::WindowID DisplayServerX11::_create_window(WindowMode p_mode, V
}
/* set the titlebar name */
- XStoreName(x11_display, wd.x11_window, "Godot");
+ XStoreName(x11_display, wd.x11_window, "Redot");
XSetWMProtocols(x11_display, wd.x11_window, &wm_delete, 1);
if (xdnd_aware != None) {
XChangeProperty(x11_display, wd.x11_window, xdnd_aware, XA_ATOM, 32, PropModeReplace, (unsigned char *)&xdnd_version, 1);
@@ -6217,7 +6217,7 @@ DisplayServerX11::DisplayServerX11(const String &p_rendering_driver, WindowMode
if (use_prime) {
print_line("Found discrete GPU, setting DRI_PRIME=1 to use it.");
- print_line("Note: Set DRI_PRIME=0 in the environment to disable Godot from using the discrete GPU.");
+ print_line("Note: Set DRI_PRIME=0 in the environment to disable Redot from using the discrete GPU.");
setenv("DRI_PRIME", "1", 1);
}
}
diff --git a/platform/macos/SCsub b/platform/macos/SCsub
index a10262c524..505e8b3cc2 100644
--- a/platform/macos/SCsub
+++ b/platform/macos/SCsub
@@ -126,7 +126,7 @@ files = [
"gl_manager_macos_legacy.mm",
]
-prog = env.add_program("#bin/godot", files)
+prog = env.add_program("#bin/redot", files)
if env["debug_symbols"] and env["separate_debug_symbols"]:
env.AddPostAction(prog, env.Run(platform_macos_builders.make_debug_macos))
diff --git a/platform/macos/doc_classes/EditorExportPlatformMacOS.xml b/platform/macos/doc_classes/EditorExportPlatformMacOS.xml
index 34ad52bbf6..22ad664f58 100644
--- a/platform/macos/doc_classes/EditorExportPlatformMacOS.xml
+++ b/platform/macos/doc_classes/EditorExportPlatformMacOS.xml
@@ -7,7 +7,7 @@
</description>
<tutorials>
<link title="Exporting for macOS">$DOCS_URL/tutorials/export/exporting_for_macos.html</link>
- <link title="Running Godot apps on macOS">$DOCS_URL/tutorials//export/running_on_macos.html</link>
+ <link title="Running Redot apps on macOS">$DOCS_URL/tutorials//export/running_on_macos.html</link>
</tutorials>
<members>
<member name="application/additional_plist_content" type="String" setter="" getter="">
diff --git a/platform/web/SCsub b/platform/web/SCsub
index e81f2ec516..daccd22bbf 100644
--- a/platform/web/SCsub
+++ b/platform/web/SCsub
@@ -58,7 +58,7 @@ for ext in sys_env["JS_EXTERNS"]:
sys_env["ENV"]["EMCC_CLOSURE_ARGS"] += " --externs " + ext.abspath
build = []
-build_targets = ["#bin/godot${PROGSUFFIX}.js", "#bin/godot${PROGSUFFIX}.wasm", "#bin/godot${PROGSUFFIX}.worker.js"]
+build_targets = ["#bin/redot${PROGSUFFIX}.js", "#bin/redot${PROGSUFFIX}.wasm", "#bin/redot${PROGSUFFIX}.worker.js"]
if env["dlink_enabled"]:
# Reset libraries. The main runtime will only link emscripten libraries, not godot ones.
sys_env["LIBS"] = []
@@ -78,7 +78,7 @@ if env["dlink_enabled"]:
sys = sys_env.Program(build_targets, ["web_runtime.cpp"])
# The side library, containing all Godot code.
- wasm = env.add_program("#bin/godot.side${PROGSUFFIX}.wasm", web_files)
+ wasm = env.add_program("#bin/redot.side${PROGSUFFIX}.wasm", web_files)
build = sys + [wasm[0]]
else:
# We use IDBFS. Since Emscripten 1.39.1 it needs to be linked explicitly.
@@ -96,14 +96,14 @@ engine = [
"js/engine/engine.js",
]
externs = [env.File("#platform/web/js/engine/engine.externs.js")]
-js_engine = env.CreateEngineFile("#bin/godot${PROGSUFFIX}.engine.js", engine, externs, env["threads"])
+js_engine = env.CreateEngineFile("#bin/redot${PROGSUFFIX}.engine.js", engine, externs, env["threads"])
env.Depends(js_engine, externs)
wrap_list = [
build[0],
js_engine,
]
-js_wrapped = env.Textfile("#bin/godot", [env.File(f) for f in wrap_list], TEXTFILESUFFIX="${PROGSUFFIX}.wrapped.js")
+js_wrapped = env.Textfile("#bin/redot", [env.File(f) for f in wrap_list], TEXTFILESUFFIX="${PROGSUFFIX}.wrapped.js")
# 0 - unwrapped js file (use wrapped one instead)
# 1 - wasm file
diff --git a/platform/web/eslint.config.cjs b/platform/web/eslint.config.cjs
index 8913a738f6..358c5c30a2 100644
--- a/platform/web/eslint.config.cjs
+++ b/platform/web/eslint.config.cjs
@@ -130,6 +130,7 @@ module.exports = [
...globals.browser,
'Features': true,
'Godot': true,
+ 'Redot': true,
'InternalConfig': true,
'Preloader': true,
},
diff --git a/platform/web/export/export_plugin.cpp b/platform/web/export/export_plugin.cpp
index d8c1b6033d..2c72bbcb3e 100644
--- a/platform/web/export/export_plugin.cpp
+++ b/platform/web/export/export_plugin.cpp
@@ -217,7 +217,7 @@ Error EditorExportPlatformWeb::_add_manifest_icon(const String &p_path, const St
Error EditorExportPlatformWeb::_build_pwa(const Ref<EditorExportPreset> &p_preset, const String p_path, const Vector<SharedObject> &p_shared_objects) {
String proj_name = GLOBAL_GET("application/config/name");
if (proj_name.is_empty()) {
- proj_name = "Godot Game";
+ proj_name = "Redot Game";
}
// Service worker
@@ -387,7 +387,7 @@ Ref<Texture2D> EditorExportPlatformWeb::get_logo() const {
bool EditorExportPlatformWeb::has_valid_export_configuration(const Ref<EditorExportPreset> &p_preset, String &r_error, bool &r_missing_templates, bool p_debug) const {
#ifdef MODULE_MONO_ENABLED
// Don't check for additional errors, as this particular error cannot be resolved.
- r_error += TTR("Exporting to Web is currently not supported in Godot 4 when using C#/.NET. Use Godot 3 to target Web with C#/Mono instead.") + "\n";
+ r_error += TTR("Exporting to Web is currently not supported in Redot 4 when using C#/.NET. Use Redot 3 to target Web with C#/Mono instead.") + "\n";
r_error += TTR("If this project does not use C#, use a non-C# editor build to export the project.") + "\n";
return false;
#else
diff --git a/platform/web/js/engine/config.js b/platform/web/js/engine/config.js
index 61b488cf81..e4aec319c5 100644
--- a/platform/web/js/engine/config.js
+++ b/platform/web/js/engine/config.js
@@ -293,7 +293,7 @@ const InternalConfig = function (initConfig) { // eslint-disable-line no-unused-
return {};
},
'locateFile': function (path) {
- if (!path.startsWith('godot.')) {
+ if (!path.startsWith('godot.') && !path.startsWith('redot.')) {
return path;
} else if (path.endsWith('.worker.js')) {
return `${loadPath}.worker.js`;
diff --git a/platform/web/js/engine/engine.externs.js b/platform/web/js/engine/engine.externs.js
index 35a66a93ae..a0d38fcd3b 100644
--- a/platform/web/js/engine/engine.externs.js
+++ b/platform/web/js/engine/engine.externs.js
@@ -1,4 +1,4 @@
-var Godot;
+var Redot;
var WebAssembly = {};
WebAssembly.instantiate = function(buffer, imports) {};
WebAssembly.instantiateStreaming = function(response, imports) {};
diff --git a/platform/web/js/engine/engine.js b/platform/web/js/engine/engine.js
index 04c4c44c5e..9718c9fd5a 100644
--- a/platform/web/js/engine/engine.js
+++ b/platform/web/js/engine/engine.js
@@ -93,7 +93,7 @@ const Engine = (function () {
return new Promise(function (resolve, reject) {
promise.then(function (response) {
const cloned = new Response(response.clone().body, { 'headers': [['content-type', 'application/wasm']] });
- Godot(me.config.getModuleConfig(loadPath, cloned)).then(function (module) {
+ Redot(me.config.getModuleConfig(loadPath, cloned)).then(function (module) {
const paths = me.config.persistentPaths;
module['initFS'](paths).then(function (err) {
me.rtenv = module;
diff --git a/platform/windows/SCsub b/platform/windows/SCsub
index f8ed8b73f5..6902d63cc7 100644
--- a/platform/windows/SCsub
+++ b/platform/windows/SCsub
@@ -55,7 +55,7 @@ env.Depends(res_obj, "#core/version_generated.gen.h")
env.add_source_files(sources, common_win)
sources += res_obj
-prog = env.add_program("#bin/godot", sources, PROGSUFFIX=env["PROGSUFFIX"])
+prog = env.add_program("#bin/redot", sources, PROGSUFFIX=env["PROGSUFFIX"])
arrange_program_clean(prog)
# Build console wrapper app.
@@ -73,7 +73,7 @@ if env["windows_subsystem"] == "gui":
env_wrap.Append(LINKFLAGS=["-Wl,--subsystem,console"])
env_wrap.Append(LIBS=["version"])
- prog_wrap = env_wrap.add_program("#bin/godot", common_win_wrap + res_wrap_obj, PROGSUFFIX=env["PROGSUFFIX_WRAP"])
+ prog_wrap = env_wrap.add_program("#bin/redot", common_win_wrap + res_wrap_obj, PROGSUFFIX=env["PROGSUFFIX_WRAP"])
arrange_program_clean(prog_wrap)
env_wrap.Depends(prog_wrap, prog)
sources += common_win_wrap + res_wrap_obj
diff --git a/platform/windows/display_server_windows.cpp b/platform/windows/display_server_windows.cpp
index 74d651d495..0d74b22c26 100644
--- a/platform/windows/display_server_windows.cpp
+++ b/platform/windows/display_server_windows.cpp
@@ -1388,7 +1388,7 @@ void DisplayServerWindows::screen_set_keep_on(bool p_enable) {
}
if (p_enable) {
- const String reason = "Godot Engine running with display/window/energy_saving/keep_screen_on = true";
+ const String reason = "Redot Engine running with display/window/energy_saving/keep_screen_on = true";
Char16String reason_utf16 = reason.utf16();
REASON_CONTEXT context;
diff --git a/platform/windows/export/export_plugin.cpp b/platform/windows/export/export_plugin.cpp
index 12694b0155..0351a4f56b 100644
--- a/platform/windows/export/export_plugin.cpp
+++ b/platform/windows/export/export_plugin.cpp
@@ -433,13 +433,13 @@ void EditorExportPlatformWindows::get_export_options(List<ExportOption> *r_optio
"$trigger = New-ScheduledTaskTrigger -Once -At 00:00\n"
"$settings = New-ScheduledTaskSettingsSet\n"
"$task = New-ScheduledTask -Action $action -Trigger $trigger -Settings $settings\n"
- "Register-ScheduledTask godot_remote_debug -InputObject $task -Force:$true\n"
- "Start-ScheduledTask -TaskName godot_remote_debug\n"
- "while (Get-ScheduledTask -TaskName godot_remote_debug | ? State -eq running) { Start-Sleep -Milliseconds 100 }\n"
- "Unregister-ScheduledTask -TaskName godot_remote_debug -Confirm:$false -ErrorAction:SilentlyContinue";
+ "Register-ScheduledTask redot_remote_debug -InputObject $task -Force:$true\n"
+ "Start-ScheduledTask -TaskName redot_remote_debug\n"
+ "while (Get-ScheduledTask -TaskName redot_remote_debug | ? State -eq running) { Start-Sleep -Milliseconds 100 }\n"
+ "Unregister-ScheduledTask -TaskName redot_remote_debug -Confirm:$false -ErrorAction:SilentlyContinue";
- String cleanup_script = "Stop-ScheduledTask -TaskName godot_remote_debug -ErrorAction:SilentlyContinue\n"
- "Unregister-ScheduledTask -TaskName godot_remote_debug -Confirm:$false -ErrorAction:SilentlyContinue\n"
+ String cleanup_script = "Stop-ScheduledTask -TaskName redot_remote_debug -ErrorAction:SilentlyContinue\n"
+ "Unregister-ScheduledTask -TaskName redot_remote_debug -Confirm:$false -ErrorAction:SilentlyContinue\n"
"Remove-Item -Recurse -Force '{temp_dir}'";
r_options->push_back(ExportOption(PropertyInfo(Variant::BOOL, "ssh_remote_deploy/enabled"), false, true));
diff --git a/platform/windows/godot.ico b/platform/windows/godot.ico
deleted file mode 100644
index f0bb68225d..0000000000
--- a/platform/windows/godot.ico
+++ /dev/null
Binary files differ
diff --git a/platform/windows/godot_console.ico b/platform/windows/godot_console.ico
deleted file mode 100644
index 1d27e3d6ae..0000000000
--- a/platform/windows/godot_console.ico
+++ /dev/null
Binary files differ
diff --git a/platform/windows/godot_res.rc b/platform/windows/godot_res.rc
index 86191ad9d9..a3f42dfc66 100644
--- a/platform/windows/godot_res.rc
+++ b/platform/windows/godot_res.rc
@@ -4,7 +4,7 @@
#define RT_MANIFEST 24
#endif
-GODOT_ICON ICON platform/windows/godot.ico
+GODOT_ICON ICON platform/windows/redot.ico
1 RT_MANIFEST "godot.manifest"
1 VERSIONINFO
@@ -17,13 +17,13 @@ BEGIN
BEGIN
BLOCK "040904b0"
BEGIN
- VALUE "CompanyName", "Godot Engine"
+ VALUE "CompanyName", "Redot Engine"
VALUE "FileDescription", VERSION_NAME
VALUE "FileVersion", VERSION_NUMBER
VALUE "ProductName", VERSION_NAME
VALUE "Licence", "MIT"
- VALUE "LegalCopyright", "(c) 2007-present Juan Linietsky, Ariel Manzur and Godot Engine contributors"
- VALUE "Info", "https://godotengine.org"
+ VALUE "LegalCopyright", "(c) 2007-present Juan Linietsky, Ariel Manzur and Redot Engine and Godot Engine contributors"
+ VALUE "Info", "https://redotengine.org"
VALUE "ProductVersion", VERSION_FULL_BUILD
END
END
diff --git a/platform/windows/godot_res_wrap.rc b/platform/windows/godot_res_wrap.rc
index 27ad26cbc5..0775cbd4eb 100644
--- a/platform/windows/godot_res_wrap.rc
+++ b/platform/windows/godot_res_wrap.rc
@@ -1,6 +1,6 @@
#include "core/version.h"
-GODOT_ICON ICON platform/windows/godot_console.ico
+GODOT_ICON ICON platform/windows/redot_console.ico
1 VERSIONINFO
FILEVERSION VERSION_MAJOR,VERSION_MINOR,VERSION_PATCH,0
@@ -12,13 +12,13 @@ BEGIN
BEGIN
BLOCK "040904b0"
BEGIN
- VALUE "CompanyName", "Godot Engine"
+ VALUE "CompanyName", "Redot Engine"
VALUE "FileDescription", VERSION_NAME " (Console)"
VALUE "FileVersion", VERSION_NUMBER
VALUE "ProductName", VERSION_NAME " (Console)"
VALUE "Licence", "MIT"
- VALUE "LegalCopyright", "(c) 2007-present Juan Linietsky, Ariel Manzur and Godot Engine contributors"
- VALUE "Info", "https://godotengine.org"
+ VALUE "LegalCopyright", "(c) 2007-present Juan Linietsky, Ariel Manzur and Redot Engine and Godot Engine contributors"
+ VALUE "Info", "https://redotengine.org"
VALUE "ProductVersion", VERSION_FULL_BUILD
END
END
diff --git a/platform/windows/redot.ico b/platform/windows/redot.ico
new file mode 100644
index 0000000000..e7ff03dfb8
--- /dev/null
+++ b/platform/windows/redot.ico
Binary files differ
diff --git a/platform/windows/redot_console.ico b/platform/windows/redot_console.ico
new file mode 100644
index 0000000000..542d8e3a49
--- /dev/null
+++ b/platform/windows/redot_console.ico
Binary files differ
diff --git a/platform/web/detect.py b/platform/web/detect.py
index bf75c2f9fc..d0a4bdb774 100644
--- a/platform/web/detect.py
+++ b/platform/web/detect.py
@@ -32,7 +32,7 @@ def get_opts():
return [
("initial_memory", "Initial WASM memory (in MiB)", 32),
# Matches default values from before Emscripten 3.1.27. New defaults are too low for Godot.
("stack_size", "WASM stack size (in KiB)", 5120),
("default_pthread_stack_size", "WASM pthread default stack size (in KiB)", 2048),
BoolVariable("use_assertions", "Use Emscripten runtime assertions", False),
@@ -278,8 +278,8 @@ def configure(env: "SConsEnvironment"):
# Reduce code size by generating less support code (e.g. skip NodeJS support).
env.Append(LINKFLAGS=["-sENVIRONMENT=web,worker"])
- # Wrap the JavaScript support code around a closure named Godot.
- env.Append(LINKFLAGS=["-sMODULARIZE=1", "-sEXPORT_NAME='Godot'"])
+ # Wrap the JavaScript support code around a closure named Redot.
+ env.Append(LINKFLAGS=["-sMODULARIZE=1", "-sEXPORT_NAME='Redot'"])
# Force long jump mode to 'wasm'
env.Append(CCFLAGS=["-sSUPPORT_LONGJMP='wasm'"])
@@ -32,7 +32,7 @@ def get_opts():
return [
("initial_memory", "Initial WASM memory (in MiB)", 32),
- # Matches default values from before Emscripten 3.1.27. New defaults are too low for Godot.
+ # Matches default values from before Emscripten 3.1.27. New defaults are too low for Redot.
("stack_size", "WASM stack size (in KiB)", 5120),
("default_pthread_stack_size", "WASM pthread default stack size (in KiB)", 2048),